@@ -35,9 +35,14 @@ module CollectiveIdea #:nodoc:
             end
           end
 
+          # Use reverse to delete from deepest child to parent in order to respect any possible foreign keys
+          def decendants_to_destroy_in_order
+            descendants.reverse
+          end
+
           def destroy_or_delete_descendants
             if acts_as_nested_set_options[:dependent] == :destroy
-              descendants.each do |model|
+              decendants_to_destroy_in_order.each do |model|
                 model.skip_before_destroy = true
                 model.destroy
               end
@@ -47,8 +52,13 @@ module CollectiveIdea #:nodoc:
             elsif acts_as_nested_set_options[:dependent] == :restrict_with_error
               unless leaf?
                 record = self.class.human_attribute_name(:children).downcase
-                errors.add(:base, :"restrict_dependent_destroy.#{Rails::VERSION::MAJOR < 5 ? 'many' : 'has_many'}", record: record)
-                return false
+                if Rails::VERSION::MAJOR < 5
+                  errors.add(:base, :"restrict_dependent_destroy.many", record: record)
+                  return false
+                else
+                  errors.add(:base, :"restrict_dependent_destroy.has_many", record: record)
+                  throw :abort
+                end
               end
               return true
              elsif acts_as_nested_set_options[:dependent] == :nullify
